@@ -11,13 +11,13 @@ from torch.nn.common_types import _size_2_t
 
 
 def _default_2d_filter():
-    default_filter = np.array([[[
+    default_filter = torch.tensor([[[
         [1, 2, 1],
         [2, 4, 2],
         [1, 2, 1],
     ]]]) * 1 / 16.0
 
-    return torch.Tensor(default_filter)
+    return default_filter
 
 
 def _padding_for_filt_2d_same(filt: torch.Tensor):
@@ -33,10 +33,10 @@ def blur_2d(input: torch.Tensor, stride: _size_2_t = 1, filter: Optional[torch.T
     """Apply a spatial low-pass filter.
 
     Args:
-        input (torch.Tensor): a 4d tensor of shape NCHW
+        input (:class:`torch.Tensor`): a 4d tensor of shape NCHW
         stride (int or tuple, optional): stride(s) along H and W axes. If a single value is passed, this
             value is used for both dimensions.
-        filter (torch.Tensor, optional): a 2d or 4d tensor to be cross-correlated with the input tensor
+        filter (:class:`torch.Tensor`, optional): a 2d or 4d tensor to be cross-correlated with the input tensor
             at each spatial position, within each channel. If 4d, the structure
             is required to be ``(C, 1, kH, kW)`` where ``C`` is the number of
             channels in the input tensor and ``kH`` and ``kW`` are the spatial
@@ -74,7 +74,7 @@ def blur_2d(input: torch.Tensor, stride: _size_2_t = 1, filter: Optional[torch.T
 
 
 def blurmax_pool2d(input: torch.Tensor,
-                   kernel_size: _size_2_t = (2, 2),
+                   kernel_size: Optional[_size_2_t] = None,
                    stride: _size_2_t = 2,
                    padding: _size_2_t = 0,
                    dilation: _size_2_t = 1,
@@ -98,20 +98,20 @@ def blurmax_pool2d(input: torch.Tensor,
     See also: :func:`~blur_2d`.
 
     Args:
-        input (torch.Tensor): a 4d tensor of shape NCHW
+        input (:class:`torch.Tensor`): a 4d tensor of shape NCHW
         kernel_size (int or tuple, optional): size(s) of the spatial neighborhoods over which to pool.
             This is mostly commonly 2x2. If only a scalar ``s`` is provided, the
-            neighborhood is of size ``(s, s)``.
+            neighborhood is of size ``(s, s)``. Default: ``(2, 2)``.
         stride (int or tuple, optional): stride(s) along H and W axes. If a single value is passed, this
-            value is used for both dimensions.
+            value is used for both dimensions. Default: 2.
         padding (int or tuple, optional): implicit zero-padding to use. For the default 3x3 low-pass
             filter, ``padding=1`` (the default) returns output of the same size
-            as the input.
+            as the input. Default: 0.
         dilation (int or tuple, optional): amount by which to "stretch" the pooling region for a given
             total size. See :class:`~torch.nn.MaxPool2d`
-            for our favorite explanation of how this works.
-        ceil_mode (bool): when True, will use ceil instead of floor to compute the output shape
-        filter (torch.Tensor, optional): a 2d or 4d tensor to be cross-correlated with the input tensor
+            for our favorite explanation of how this works. Default: 1.
+        ceil_mode (bool): when True, will use ceil instead of floor to compute the output shape. Default: ``False``.
+        filter (:class:`torch.Tensor`, optional): a 2d or 4d tensor to be cross-correlated with the input tensor
             at each spatial position, within each channel. If 4d, the structure
             is required to be ``(C, 1, kH, kW)`` where ``C`` is the number of
             channels in the input tensor and ``kH`` and ``kW`` are the spatial
@@ -128,6 +128,9 @@ def blurmax_pool2d(input: torch.Tensor,
     Returns:
          The blurred and max-pooled input
     """
+    if kernel_size is None:
+        kernel_size = (2, 2)
+
     maxs = F.max_pool2d(input,
                         kernel_size=kernel_size,
                         stride=1,
@@ -197,7 +200,7 @@ class BlurConv2d(nn.Module):
     applied.
 
     The one new parameter is ``blur_first``. When set to ``True``, the
-    anti-aliasing filter is applied before the underlying convolution, and
+    anti-aliasing filter is applied before the underlying convolution and
     vice-versa when set to ``False``. This mostly makes a difference when the
     stride is greater than one. In the former case, the only overhead is the
     cost of doing the anti-aliasing operation. In the latter case, the ``Conv2d``
