@@ -1,5 +1,7 @@
 # Copyright 2021 MosaicML. All Rights Reserved.
 
+"""Core SelectiveBackprop class and functions."""
+
 from __future__ import annotations
 
 import inspect
@@ -13,6 +15,8 @@ from composer.core import Algorithm, Event, State
 from composer.loggers import Logger
 from composer.models import ComposerModel
 
+__all__ = ['SelectiveBackprop', 'select_using_loss', 'should_selective_backprop']
+
 
 def should_selective_backprop(
     current_duration: float,
@@ -21,10 +25,10 @@ def should_selective_backprop(
     end: float = 0.9,
     interrupt: int = 2,
 ) -> bool:
-    """Decide if selective backprop should be run based on time in training.
+    """Decides if selective backprop should be run based on time in training.
 
     Returns true if the ``current_duration`` is between ``start`` and
-    ``end``. Recommend that SB be applied during the later stages of
+    ``end``. It is recommended that SB be applied during the later stages of
     a training run, once the model has already "learned" easy examples.
 
     To preserve convergence, SB can be interrupted with vanilla minibatch
@@ -58,14 +62,9 @@ def select_using_loss(input: torch.Tensor,
                       loss_fun: Callable,
                       keep: float = 0.5,
                       scale_factor: float = 1) -> Tuple[torch.Tensor, torch.Tensor]:
-    """Selectively backpropagate gradients from a subset of each batch (`Jiang et al, 2019 <https://\\
-    arxiv.org/abs/1910.00762>`_).
-
-    Selective Backprop (SB) prunes minibatches according to the difficulty
-    of the individual training examples and only computes weight gradients
-    over the selected subset. This reduces iteration time and speeds up training.
-    The fraction of the minibatch that is kept for gradient computation is
-    specified by the argument ``0 <= keep <= 1``.
+    """Prunes minibatches as a subroutine of SelectiveBackprop. Computes the loss function on the provided training
+    examples and runs minibatches according to the difficulty. The fraction of the minibatch that is kept for gradient
+    computation is specified by the argument ``0 <= keep <= 1``.
 
     To speed up SB's selection forward pass, the argument ``scale_factor`` can
     be used to spatially downsample input tensors. The full-sized inputs
@@ -89,15 +88,23 @@ def select_using_loss(input: torch.Tensor,
         ValueError: If ``scale_factor > 1``
         TypeError: If ``loss_fun > 1`` has the wrong signature or is not callable
 
-    Note:
-    This function runs an extra forward pass through the model on the batch of data.
-    If you are using a non-default precision, ensure that this forward pass
-    runs in your desired precision. For example:
+    .. note::
 
-    .. code-block:: python
+        This function runs an extra forward pass through the model on the batch of data.
+        If you are using a non-default precision, ensure that this forward pass
+        runs in your desired precision. For example:
 
+    .. testsetup::
+
+        N_sb, D_sb = 16, 8
+        X_sb, y_sb = torch.randn(N_sb, D_sb), torch.randint(2, (N_sb,))
+        lin_model = torch.nn.Linear(X_sb.shape[1], 1)
+
+    .. doctest::
+
+        from composer.algorithms.selective_backprop import select_using_loss
         with torch.cuda.amp.autocast(True):
-            X_new, y_new = selective_backprop(X, y, model, loss_fun, keep, scale_factor)
+            X_new, y_new = select_using_loss(X_sb, y_sb, lin_model, loss_fun, keep=0.5, scale_factor=1)
     """
     INTERPOLATE_MODES = {3: "linear", 4: "bilinear", 5: "trilinear"}
 
@@ -145,35 +152,52 @@ def select_using_loss(input: torch.Tensor,
 
 
 class SelectiveBackprop(Algorithm):
-    """Selectively backpropagate gradients from a subset of each batch (`Jiang et al, 2019 <https://\\
-    arxiv.org/abs/1910.00762>`_).
+    """Selectively backpropagate gradients from a subset of each batch.
 
-    Selective Backprop (SB) prunes minibatches according to the difficulty
-    of the individual training examples, and only computes weight gradients
-    over the pruned subset, reducing iteration time and speeding up training.
-    The fraction of the minibatch that is kept for gradient computation is
-    specified by the argument ``0 <= keep <= 1``.
+     Based on (`Jiang et al, 2019`_), Selective Backprop (SB) prunes minibatches
+     according to the difficulty of the individual training examples, and only
+     computes weight gradients over the pruned subset, reducing iteration time and
+     speeding up training.
 
-    To speed up SB's selection forward pass, the argument ``scale_factor`` can
-    be used to spatially downsample input image tensors. The full-sized inputs
-    will still be used for the weight gradient computation.
+     The fraction of the minibatch that is kept for gradient computation is
+     specified by the argument ``0 <= keep <= 1``.
 
-    To preserve convergence, SB can be interrupted with vanilla minibatch
-    gradient steps every ``interrupt`` steps. When ``interrupt=0``, SB will be
-    used at every step during the SB interval. When ``interrupt=2``, SB will
-    alternate with vanilla minibatch steps.
+     To speed up SB's selection forward pass, the argument ``scale_factor`` can
+     be used to spatially downsample input image tensors. The full-sized inputs
+     will still be used for the weight gradient computation.
 
-    Args:
-        start (float, optional): SB interval start as fraction of training duration
-            Default: ``0.5``.
-        end (float, optional): SB interval end as fraction of training duration
-            Default: ``0.9``.
-        keep (float, optional): fraction of minibatch to select and keep for gradient computation
-            Default: ``0.5``.
-        scale_factor (float, optional): scale for downsampling input for selection forward pass
-            Default: ``0.5``.
-        interrupt (int, optional): interrupt SB with a vanilla minibatch step every
-            ``interrupt`` batches. Default: ``2``.
+     To preserve convergence, SB can be interrupted with vanilla minibatch
+     gradient steps every ``interrupt`` steps. When ``interrupt=0``, SB will be
+     used at every step during the SB interval. When ``interrupt=2``, SB will
+     alternate with vanilla minibatch steps.
+
+     .. _Jiang et al, 2019: https://arxiv.org/abs/1910.00762
+
+     Args:
+         start (float, optional): SB interval start as fraction of training duration
+             Default: ``0.5``.
+         end (float, optional): SB interval end as fraction of training duration
+             Default: ``0.9``.
+         keep (float, optional): fraction of minibatch to select and keep for gradient computation
+             Default: ``0.5``.
+         scale_factor (float, optional): scale for downsampling input for selection forward pass
+             Default: ``0.5``.
+         interrupt (int, optional): interrupt SB with a vanilla minibatch step every
+             ``interrupt`` batches. Default: ``2``.
+
+    Example:
+         .. testcode::
+
+             from composer.algorithms import SelectiveBackprop
+             algorithm = SelectiveBackprop(start=0.5, end=0.9, keep=0.5)
+             trainer = Trainer(
+                 model=model,
+                 train_dataloader=train_dataloader,
+                 eval_dataloader=eval_dataloader,
+                 max_duration="1ep",
+                 algorithms=[algorithm],
+                 optimizers=[optimizer]
+             )
     """
 
     def __init__(self,
@@ -190,11 +214,6 @@ class SelectiveBackprop(Algorithm):
         self._loss_fn = None  # set on Event.INIT
 
     def match(self, event: Event, state: State) -> bool:
-        """Matches :attr:`Event.INIT` and `Event.AFTER_DATALOADER`
-
-        * Uses `Event.INIT` to get the loss function before the model is wrapped
-        * Uses `Event.AFTER_DATALOADER`` to apply selective backprop if time is between ``self.start`` and ``self.end``.
-        """
         if event == Event.INIT:
             return True
         if event != Event.AFTER_DATALOADER:
@@ -214,7 +233,6 @@ class SelectiveBackprop(Algorithm):
         return is_chosen
 
     def apply(self, event: Event, state: State, logger: Optional[Logger] = None) -> None:
-        """Apply selective backprop to the current batch."""
         if event == Event.INIT:
             if self._loss_fn is None:
                 if not isinstance(state.model, ComposerModel):
