@@ -4,13 +4,15 @@
 from __future__ import annotations
 
 import abc
-from typing import Any, Sequence, Tuple, Union
+import copy
+from typing import Any, Optional, Sequence, Tuple, Union
 
 import torch
 from torch import Tensor
 from torchmetrics import Metric, MetricCollection
 
 from composer.core.types import Batch
+from composer.loggers import Logger
 
 __all__ = ["ComposerModel"]
 
@@ -48,8 +50,44 @@ class ComposerModel(torch.nn.Module, abc.ABC):
                 # pass batches and `forward` outputs to the loss
                 _, targets = batch
                 return F.cross_entropy(outputs, targets)
+
+    Attributes:
+        logger (Optional[Logger]): The training :class:`.Logger`.
+            The trainer sets the :class:`.Logger` on the:attr:`~composer.core.event.Event.INIT` event.
     """
 
+    def __init__(self) -> None:
+        super().__init__()
+        self.logger: Optional[Logger] = None
+
+    def __deepcopy__(self, memo: dict):
+        # From https://stackoverflow.com/questions/1500718/how-to-override-the-copy-deepcopy-operations-for-a-python-object
+        # The `logger` should not be copied
+        cls = self.__class__
+        result = cls.__new__(cls)
+        memo[id(self)] = result
+        for k, v in self.__dict__.items():
+            if k == "logger":
+                copied_v = v
+            else:
+                copied_v = copy.deepcopy(v, memo)
+            setattr(result, k, copied_v)
+        return result
+
+    def __copy__(self):
+        # From https://stackoverflow.com/questions/1500718/how-to-override-the-copy-deepcopy-operations-for-a-python-object
+        # Need to manually define `__copy__` so it does not rely on `__getstate__`, which would not copy the logger.
+        cls = self.__class__
+        result = cls.__new__(cls)
+        result.__dict__.update(self.__dict__)
+        return result
+
+    def __getstate__(self):
+        # Don't pickle the logger
+        state = self.__dict__.copy()
+        state['logger'] = None
+        return state
+
     @abc.abstractmethod
     def forward(self, batch: Batch) -> Union[Tensor, Sequence[Tensor]]:
         """Compute model output given a batch from the dataloader.
