@@ -566,6 +566,7 @@ class Trainer:
         torch_prof_with_flops: bool = True,
         torch_prof_num_traces_to_keep: int = -1,
     ):
+
         # surpressing GradScaler warnings as they are always created
         # self._use_grad_scaling() will raise a RuntimeError if grad scaling is not available when it is required
         warnings.filterwarnings(action="ignore", message="torch.cuda.amp.GradScaler")
@@ -868,6 +869,9 @@ class Trainer:
         else:
             self.train_metrics = None
 
+        # Set the logger
+        model.logger = self.logger
+
         self.engine.run_event(Event.INIT)
 
         assert isinstance(self.state.model, ComposerModel)
@@ -961,10 +965,15 @@ class Trainer:
 
     def fit(self):
         """Train and evaluate the model on the provided data."""
-        try:
-            self._train_loop()
-        finally:
-            self.engine.close()
+        # Print any exception, so it can be caputred by any callbacks or loggers (e.g. WandB, FileLogger)
+        self._train_loop()
+
+    def close(self):
+        """Shutdown the trainer.
+
+        .. seealso:: :meth:`.Engine.close` for additional information.
+        """
+        self.engine.close()
 
     def _ensure_metrics_device_and_dtype(self, metrics: MetricCollection):
         # Safety check to ensure the metric and data are on the same device. Normally not
@@ -1216,7 +1225,7 @@ class Trainer:
             except RuntimeError as e:
                 if self._is_cuda_oom(e):
                     log.debug(
-                        textwrap.dedent(f"""Rank {dist.get_global_rank()} OOM'd. 
+                        textwrap.dedent(f"""Rank {dist.get_global_rank()} OOM'd.
                         grad_accum will be increased prior to reattempting training on the current batch."""))
                     should_handle_cuda_oom = 1
                 elif "Timed out" in str(e):
