@@ -4,6 +4,7 @@
 from composer.utils.checkpoint import load_checkpoint, save_checkpoint
 from composer.utils.file_helpers import (ensure_folder_is_empty, format_name_with_dist, format_name_with_dist_and_time,
                                          get_file, is_tar)
+from composer.utils.collect_env import configure_excepthook, disable_env_report, enable_env_report, print_env
 from composer.utils.import_helpers import MissingConditionalImportError, import_object
 from composer.utils.iter_helpers import ensure_tuple, iterate_with_pbar, map_collection
 from composer.utils.object_store import ObjectStore, ObjectStoreHparams
@@ -25,4 +26,8 @@ __all__ = [
     'format_name_with_dist',
     'format_name_with_dist_and_time',
     'is_tar',
+    'configure_excepthook',
+    'disable_env_report',
+    'enable_env_report',
+    'print_env',
 ]
